@@ -198,7 +198,7 @@ def load_shortcuts(smart_bookmarks, shortcuts_to_smart_bookmarks_map):
     shortcuts_to_smart_bookmarks_map.clear()
     url_to_shortcuts = {}
     try:
-        for line in file(os.path.join(deskbar.USER_DESKBAR_DIR, "search-bookmarks-shortcuts.txt")):
+        for line in file(os.path.join(deskbar.USER_CONFIG_DIR, "search-bookmarks-shortcuts.txt")):
             line = line.strip()
             if len(line) > 0:
                 url, shortcut = line.split()
@@ -214,7 +214,7 @@ def load_shortcuts(smart_bookmarks, shortcuts_to_smart_bookmarks_map):
             pass
 
 def _save_shortcuts(shortcuts_to_smart_bookmarks_map):
-    f = open(os.path.join(deskbar.USER_DESKBAR_DIR, "search-bookmarks-shortcuts.txt"), "w")
+    f = open(os.path.join(deskbar.USER_CONFIG_DIR, "search-bookmarks-shortcuts.txt"), "w")
     for shortcut in shortcuts_to_smart_bookmarks_map.keys():
         bookmark = shortcuts_to_smart_bookmarks_map[shortcut]
         f.write(bookmark.url)
@@ -235,9 +235,10 @@ def on_customize_search_shortcuts(smart_bookmarks, shortcuts_to_smart_bookmarks_
     list_store = gtk.ListStore(str, gobject.TYPE_PYOBJECT)
     _sync_list_store_from_shortcuts_map(list_store, smart_bookmarks, shortcuts_to_smart_bookmarks_map)
     
-    glade = gtk.glade.XML(os.path.join(deskbar.SHARED_DATA_DIR, "smart-bookmarks.glade"))
+    builder = gtk.Builder()
+    builder.add_from_file(os.path.join(deskbar.SHARED_DATA_DIR, "smart-bookmarks.ui"))
     
-    view = glade.get_widget("bookmarks-view")
+    view = builder.get_object("bookmarks-view")
     view.set_model(list_store)
     
     crt_shortcut = gtk.CellRendererText()
@@ -255,7 +256,7 @@ def on_customize_search_shortcuts(smart_bookmarks, shortcuts_to_smart_bookmarks_
     tvc_name.set_cell_data_func(crt_name, bookmark_to_bookmark_name)
     view.append_column(tvc_name)
     
-    dialog = glade.get_widget("smart-bookmarks")
+    dialog = builder.get_object("smart-bookmarks")
     dialog.set_icon_name("deskbar-applet")
     dialog.show_all()
     dialog.run()
